@@ -110,6 +110,7 @@ extern void  brktty __P((int));
 extern struct baud_values *lookup_baud __P((int bps));
 extern int   SetBaud __P((struct mode *, int, int));
 extern int   SttyMode __P((struct mode *, char *));
+extern int   CheckTtyname __P((char *));
 
 
 /* mark.c */
@@ -445,7 +446,7 @@ extern void  LSetFlow __P((struct layer *, int));
 extern void  LKeypadMode __P((struct layer *, int));
 extern void  LCursorkeysMode __P((struct layer *, int));
 extern void  LMouseMode __P((struct layer *, int));
-#ifdef USEVARARGS
+#if defined(USEVARARGS)
 extern void  LMsg __P((int, const char *, ...)) __attribute__((format(printf, 2, 3)));
 #else
 extern void  LMsg __P(());
@@ -458,8 +459,7 @@ extern void  LayProcessMouseSwitch __P((struct layer *, int));
 
 /* teln.c */
 #ifdef BUILTIN_TELNET
-extern int   TelOpen __P((char **));
-extern int   TelConnect __P((struct win *));
+extern int   TelOpenAndConnect __P((struct win *));
 extern int   TelIsline __P((struct win *p));
 extern void  TelProcessLine __P((char **, int *));
 extern int   DoTelnet __P((char *, int *, int));
@@ -502,3 +502,7 @@ extern int   PrepareEncodedChar __P((int));
 # endif
 #endif
 extern int   EncodeChar __P((char *, int, int, int *));
+
+/* layout.c */
+extern void  RemoveLayout __P((struct layout *));
+extern int   LayoutDumpCanvas __P((struct canvas *, char *));
